@@ -14,7 +14,7 @@ normal = "Normal"
 
 class ITBObject:
     def __init__(self):
-        self.version = "1.0.3"
+        self.version = "1.0.7"
         self.author = "Ludy87"
         self.project = "Ich tanke billig"
         self.page = "https://www.astra-g.org/"
@@ -33,7 +33,7 @@ def connenctionLib(url):
         return response.read()
 
 def getStations(kraftstoff = diesel, place = '123', limit = '-1', asJson = False):
-    url = baseURL + '&sprit=' + kraftstoff + '&ort=' + urllib.parse.quote(place)
+    url = baseURL + '&sprit=' + kraftstoff + '&ort=' + urllib.parse.quote(str(place))
     data = connenctionLib(url)
     text = data.decode('utf-8')
     bs = BeautifulSoup(text, 'html.parser')
